@@ -78,6 +78,12 @@ class BaseComputeNodeDriver(object):
         # information back to the cloud node appropriately.
         raise NotImplementedError("BaseComputeNodeDriver.sync_node")
 
+    @classmethod
+    def node_fqdn(cls, node):
+        # This method should return the FQDN of the node object argument.
+        # Different clouds store this in different places.
+        raise NotImplementedError("BaseComputeNodeDriver.node_fqdn")
+
     @classmethod
     def node_start_time(cls, node):
         raise NotImplementedError("BaseComputeNodeDriver.node_start_time")
