@@ -27,21 +27,12 @@ class GCEComputeNodeDriverTestCase(testutil.DriverTestMixin, unittest.TestCase):
         driver = self.new_driver(create_kwargs={'image': 'B'})
         self.assertEqual(1, list_method.call_count)
 
-    def test_list_sizes_requires_location_match(self):
-        locations = [testutil.cloud_object_mock(name)
-                     for name in ['there', 'here', 'other']]
-        self.driver_mock().list_locations.return_value = locations
-        driver = self.new_driver(create_kwargs={'location': 'HERE'})
-        driver.list_sizes()
-        self.assertIs(locations[1],
-                      self.driver_mock().list_sizes.call_args[0][0])
-
     def test_create_includes_ping_secret(self):
         arv_node = testutil.arvados_node_mock(info={'ping_secret': 'ssshh'})
         driver = self.new_driver()
         driver.create_node(testutil.MockSize(1), arv_node)
         metadata = self.driver_mock().create_node.call_args[1]['ex_metadata']
-        self.assertIn('ping_secret=ssshh', metadata.get('user-data'))
+        self.assertIn('ping_secret=ssshh', metadata.get('arv-ping-url'))
 
     def test_create_sets_default_hostname(self):
         driver = self.new_driver()
@@ -136,6 +127,19 @@ class GCEComputeNodeDriverTestCase(testutil.DriverTestMixin, unittest.TestCase):
         metadata = self.driver_mock().create_node.call_args[1]['ex_metadata']
         self.assertLessEqual(start_time, metadata.get('booted_at'))
 
+    def test_known_node_fqdn(self):
+        name = 'fqdntest.zzzzz.arvadosapi.com'
+        node = testutil.cloud_node_mock(metadata=self.build_gce_metadata(
+                {'hostname': name}))
+        self.assertEqual(name, gce.ComputeNodeDriver.node_fqdn(node))
+
+    def test_unknown_node_fqdn(self):
+        # Return an empty string.  This lets fqdn be safely compared
+        # against an expected value, and ComputeNodeMonitorActor
+        # should try to update it.
+        node = testutil.cloud_node_mock(metadata=self.build_gce_metadata({}))
+        self.assertEqual('', gce.ComputeNodeDriver.node_fqdn(node))
+
     def test_deliver_ssh_key_in_metadata(self):
         test_ssh_key = 'ssh-rsa-foo'
         arv_node = testutil.arvados_node_mock(1)
